@@ -3,8 +3,9 @@
 module Faraday
   # RequestOptions contains the configurable properties for a Faraday request.
   class RequestOptions < Options.new(:params_encoder, :proxy, :bind,
-                                     :timeout, :open_timeout, :write_timeout,
-                                     :boundary, :oauth, :context, :on_data)
+                                     :timeout, :open_timeout, :read_timeout,
+                                     :write_timeout, :boundary, :oauth,
+                                     :context, :on_data)
 
     def []=(key, value)
       if key && key.to_sym == :proxy
